@@ -12,8 +12,10 @@
 
 using namespace KPkPass;
 
-namespace KPkPass {
-class LocationPrivate {
+namespace KPkPass
+{
+class LocationPrivate
+{
 public:
     QJsonObject obj;
 };
@@ -51,3 +53,5 @@ QString Location::relevantText() const
 {
     return d->obj.value(QLatin1String("relevantText")).toString();
 }
+
+#include "moc_location.cpp"
